==> live-normal-service-api-0.4.24-1-20220518.070836-1-sources.jar: cn/com/duiba/live/normal/service/api/dto/oto/cust/CustPhaseExtDto.java <==
package cn.com.duiba.live.normal.service.api.dto.oto.cust;

import lombok.Data;

import java.io.Serializable;
import java.util.Date;

/**
 * 客户阶段流转表
 * @author kjj mybatis generator 
 * @date 2022-05-18
 */
@Data
public class CustPhaseExtDto implements Serializable {
     
    private static final long serialVersionUID = 16528533096958847L;

    /**
     * 主键
     */
    private Long id;

    /**
     * 客户id
     */
    private Long custId;

    /**
     * 客户阶流程组名称 0: 客户待分配 1:具备机构养老理念 2:认同公司养老解决方案 3:认同你的保险方案 4.当下成交 5.已成单
     */
    private Integer custFlow;

    /**
     * 客户觉得退休后到底要准备多少退休金才够用
     */
    private Integer pensionSalary;

    /**
     * 希望退休后每个月的养老生活费是多少
     */
    private Integer pensionCost;

    /**
     * 除了退休养老规划，还希望了解的有关家庭财富的板块有哪些
     */
    private String pensionOther;

    /**
     * 是否提交养老计划方案 0:否 1：是
     */
    private Integer commitPlanFlag;

    /**
     * 计划书图片
     */
    private String planPic;

    /**
     * 提交方案后客户状态 1近期有机会成交 2近期无法成交 3拒绝
     */
    private Integer commitCustStatus;

    /**
     * 客户是否已确认投保要素  0:否 1：是
     */
    private Integer commitInsure;

    /**
     * 客户未确认投保要素的原因
     */
    private String insureReason;

    /**
     * 产品ID tb_product
     */
    private Long productId;

    /**
     * 投保人 1自己 2配偶 3父母 4子女
     */
    private Integer insApplicant;

    /**
     * 被投保人 1自己 2配偶 3父母 4子女
     */
    private Integer insByApplicant;

    /**
     * 投保金额
     */
    private Integer insMoney;

    /**
     * 投保期数 0默认为趸交
     */
    private Integer insPeriod;

    /**
     * 是否成交 0:否 1:是
     */
    private Integer dealFlag;

    /**
     * 保单号
     */
    private String dealNumber;

    /**
     * 创建时间
     */
    private Date gmtCreate;

    /**
     * 更新时间
     */
    private Date gmtModified;
}

==> live-normal-service-api-0.4.24-1-20220524.080320-33-sources.jar: cn/com/duiba/live/normal/service/api/dto/oto/cust/CustPhaseExtDto.java <==
package cn.com.duiba.live.normal.service.api.dto.oto.cust;

import lombok.Data;

import java.io.Serializable;
import java.util.Date;

/**
 * 客户阶段流转表
 * @author kjj mybatis generator 
 * @date 2022-05-18
 */
@Data
public class CustPhaseExtDto implements Serializable {
     
    private static final long serialVersionUID = 16528533096958847L;

    /**
     * 主键
     */
    private Long id;

    /**
     * 客户id
     */
    private Long custId;

    /**
     * 销售id
     */
    private Long sellerId;

    /**
     * 客户阶流程组名称 0: 客户待分配 1:具备机构养老理念 2:认同公司养老解决方案 3:认同你的保险方案 4.当下成交 5.已成单
     */
    private Integer custFlow;

    /**
     * 客户觉得退休后到底要准备多少退休金才够用
     */
    private Integer pensionSalary;

    /**
     * 希望退休后每个月的养老生活费是多少
     */
    private Integer pensionCost;

    /**
     * 除了退休养老规划，还希望了解的有关家庭财富的板块有哪些
     */
    private String pensionOther;

    /**
     * 是否提交养老计划方案 0:否 1：是
     */
    private Integer commitPlanFlag;

    /**
     * 计划书图片
     */
    private String planPicUrl;

    /**
     * 提交方案后客户状态 1近期有机会成交 2近期无法成交 3拒绝
     */
    private Integer commitCustStatus;

    /**
     * 客户是否已确认投保要素  0:否 1：是
     */
    private Integer commitInsure;

    /**
     * 客户未确认投保要素的原因
     */
    private String insureReason;

    /**
     * 产品ID tb_product
     */
    private Long productId;

    /**
     * 产品名称
     */
    private String productName;

    /**
     * 投保人 1自己 2配偶 3父母 4子女
     */
    private Integer insApplicant;

    /**
     * 被投保人 1自己 2配偶 3父母 4子女
     */
    private Integer insByApplicant;

    /**
     * 投保金额
     */
    private Integer insMoney;

    /**
     * 投保期数 0默认为趸交
     */
    private Integer insPeriod;

    /**
     * 是否成交 0:否 1:是
     */
    private Integer dealFlag;

    /**
     * 保单号
     */
    private String dealNumber;

    /**
     * 创建时间
     */
    private Date gmtCreate;

    /**
     * 更新时间
     */
    private Date gmtModified;
}
